!**************************************************************************
!* Spatially Explicit Individual-Based Dynamic Global Vegetation Model    *
!* SEIB-DGVM ver. 2.00 (2008-Jan-30)                                       *
!*                                                                        *
!*   All rights are reserved by Dr. Hisashi SATO                          *
!*   @ Frontier Research Center for Global Change (FRCGC),                *
!*     Japan Agency for Marine-Earth Science and Technology (JAMSTEC)     *
!*                                                                        *
!*   Latest information and code using policy can be obtained at          *
!*   http://seib-dgvm.com/                                                *
!**************************************************************************

!*************************************************************************************************
! MAIN SIMULATION LOOP
!*************************************************************************************************
SUBROUTINE main_loop ( LAT, LON, &                        
           tmp_air, tmp_soil, cloud, prec, humid, wind,  &
           ALT, Albedo_soil0, W_fi, W_wilt, W_sat, W_mat )

!_____________ Set variables
!Namespace
   USE data_structure
   USE time_counter
   USE vegi_status_current1
   USE vegi_status_current2
   USE vegi_status_record
   USE grid_status_current1
   USE grid_status_current2
   USE grid_status_record
   implicit none
   
!Augments (Climatic data)
   real,dimension(365):: tmp_air  !2m air temperature              (Celcius) 
   real,dimension(365):: tmp_soil !soil temperature at 10 cm depth (Celcius) 
   real,dimension(365):: cloud    !total cloudiness                (fraction)
   real,dimension(365):: prec     !precipitation                   (mm day-1)
   real,dimension(365):: humid    !specific humidity               (kg kg-1) 
   real,dimension(365):: wind     !wind velocity                   (m s-1)   
   
!Augments (Location data)
   real,intent(IN):: LAT          !latitude  (degree)
   real,intent(IN):: LON          !longitude (degree)
   real,intent(IN):: ALT          !altitude  (m above MSL)
   real,intent(IN):: Albedo_soil0 !soil albedo
   real,intent(IN):: W_fi         !filed capacity   (m3/m3, 0.0 -> 1.0)
   real,intent(IN):: W_wilt       !wilting point    (m3/m3, 0.0 -> 1.0)
   real,intent(IN):: W_sat        !saturate point   (m3/m3, 0.0 -> 1.0)
   real,intent(IN):: W_mat        !matrix potential 
   
!Local variables
   integer p, no !loop counter
   real    x, y  !temporal variables for general usage
   
!_____________ Intialize variables
!Reset variables
    Call init_value (W_sat, tmp_air, tmp_soil, prec)
   
!Read spinup files
   if (Flag_spinup_read) then
      open (File_no(1), file=Fn_spnin)
      Call spinup_in (File_no(1))
      close (File_no(1))
   endif
   
!_____________ Open output files
   open ( File_no( 1), file = 'output_log.txt'          )
   open ( File_no( 2), file = 'output.txt'              )
   open ( File_no( 3), file = 'output_climate.txt'      )
   open ( File_no( 4), file = 'output_air.txt'          )
   open ( File_no( 5), file = 'output_radiation.txt'    )
   open ( File_no( 6), file = 'output_netradiation.txt' )
   open ( File_no( 7), file = 'output_water.txt'        )
   open ( File_no( 8), file = 'output_grass.txt'        )
   open ( File_no( 9), file = 'output_lai.txt'          )
   open ( File_no(10), file = 'output_cflux.txt'        )
   open ( File_no(11), file = 'output_wflux.txt'        )
   open ( File_no(12), file = 'output_ld_vertical.txt'  )
   open ( File_no(13), file = 'output_annual.txt'       )
   open ( File_no(14), file = 'output_forest.txt'       )
   open ( File_no(15), file = 'output_biomass.txt'      )
   
!_____________ Starting point of the simulation loop
   if (Flag_spinup_read) then
      counter_begin = 1 +Spinup_year*365
      counter_end   = (Simulation_year+Spinup_year) * 365
   else
      counter_begin = 1
      counter_end   = Simulation_year * 365
   endif
   
   doy  = 0
   year = 1
   
Do counter = counter_begin, counter_end

!_____________ Daily update of field status
!Time counters
   doy = doy + 1
   if (doy == 366) then
      doy   = 1
      year  = year + 1
   endif
   
!Climate statictics
   if (Logging==1) write (File_no(1),*) '    climate_stat'      !log
   Call climate_stat (tmp_air(doy), tmp_soil(doy), prec(doy))
   
!Soil hydrogy
   if (Day_of_Month(doy)==1) then
      aet(Month(doy))  = hydRecord_ev + hydRecord_tr + hydRecord_ic
      hydRecord_preci  = 0.0  !sum of precipitation      (mm/month)
      hydRecord_runoff = 0.0  !sum of runoff water       (mm/month)
      hydRecord_ic     = 0.0  !sum of interception water (mm/month)
      hydRecord_ev     = 0.0  !sum of evaporated water   (mm/month)
      hydRecord_tr     = 0.0  !sum of tranpirated water  (mm/month)
   endif
   
   pool_w1_RunningRecord(2:365) = pool_w1_RunningRecord(1:364)
   pool_w1_RunningRecord(1)     = pool_w1
   
!_____________ DAILY UPDATE OF METABOLIC STATUS
!Carbon Flux
   if (Day_of_Month(doy)==1) then
      c_emission        = 0.0
      c_uptake          = 0.0
      gpp_month (:)     = 0.0
      npp_month (:)     = 0.0
      gpp_month_ind (:) = 0.0
   endif
   
   if (doy==1) then
      gpp_annual(:) = 0.0
      npp_annual(:) = 0.0
   endif
   
   do p = 1, PFT_no
      npp_RunningRecord(p,2:365) = npp_RunningRecord(p,1:364)
      npp_RunningRecord(p,1)     = npp(p)
      
      npp_10d_ave(p) = sum ( npp_RunningRecord(p,1:10) ) / 10.0
      
      gpp_month(p)  = gpp_month(p)  + gpp(p)
      npp_month(p)  = npp_month(p)  + npp(p)
      
      gpp_annual(p) = gpp_annual(p) + gpp(p)
      npp_annual(p) = npp_annual(p) + npp(p)
      
      gpp(p)      = 0.0
      npp(p)      = 0.0
      canopy_cond = 0.0
   end do
   
!LAI
   !annual maximum and average
   if (doy==1) then
      lai_max_wood   = 0.0
      lai_max_grass  = 0.0
      lai_mean_wood  = 0.0
      lai_mean_grass = 0.0
   endif
   
   !woody PFTs
   x = 0.0
   do no=1, Max_no
      if (tree_exist(no)) x = x + la(no)
   enddo
   x = x / Max_loc / Max_loc
   
   lai_max_wood  = max(x, lai_max_wood)
   lai_mean_wood = lai_mean_wood  + x / 365.0
   
   !grass PFTs
   if (type_grass == 3) then
      x = 0.9*lai_grass(1) + 0.1*lai_grass(2)
   else
      x = 0.1*lai_grass(1) + 0.9*lai_grass(2)
   endif
   lai_max_grass  = max(x, lai_max_grass)
   lai_mean_grass = lai_mean_grass + x / 365.0
   
!Water status
   do p = 1, PFT_no
      x = max(pool_w1/Depth1, pool_w2/Depth2)
      x = (x-W_wilt) / max(0.01, W_fi-W_wilt)
      stat_water(p) = max( 0.0 , min(1.0,x) )
   enddo
   if ( tmp_soil(doy) < 0.0 ) stat_water(:) = 0.0
   
   do p = 1, PFT_no
      stat_water_RunningRecord(p,2:365) = stat_water_RunningRecord(p,1:364)
      stat_water_RunningRecord(p,1)     = stat_water(p)
   enddo
   
!Phenology
   do p = 1, PFT_no
      phenology_RunningRecord(p,2:365) = phenology_RunningRecord(p,1:364)
      phenology_RunningRecord(p,1)     = phenology(p)
   enddo
   
!Biomass density
   pool_trunc=0.0 ; pool_leaf=0.0 ; pool_root=0.0
   Do no=1, Max_no
      if ( .not. tree_exist(no) ) cycle
      pool_trunc = pool_trunc + mass_trunk(no) + mass_stock(no) + mass_available(no)
      pool_leaf  = pool_leaf  + mass_leaf(no)
      pool_root  = pool_root  + mass_root(no)
   End Do
   
   pool_grass_up=0.0 ; pool_grass_dn=0.0
   if (type_grass==3) then
      pool_grass_up = 0.9 * ( gmass_leaf(1)+gmass_available(1) ) &
                    + 0.1 * ( gmass_leaf(2)+gmass_available(2) )  
      pool_grass_dn = 0.9 * ( gmass_root(1)+gmass_stock(1) )     &
                    + 0.1 * ( gmass_root(2)+gmass_stock(2) )      
   else
      pool_grass_up = 0.1 * ( gmass_leaf(1)+gmass_available(1) ) &
                    + 0.9 * ( gmass_leaf(2)+gmass_available(2) )  
      pool_grass_dn = 0.1 * ( gmass_root(1)+gmass_stock(1) )     &
                    + 0.9 * ( gmass_root(2)+gmass_stock(2) )      
   endif
   pool_grass_up = pool_grass_up * Max_loc * Max_loc
   pool_grass_dn = pool_grass_dn * Max_loc * Max_loc
   
!Mortality related
   if (doy==1) then
      mort_regu1(:) = 0.0 !NPP annual (g / individual)
      mort_regu2(:) = 0.0 !average leaf area of last year (m2/day) {update on: growth_wood}
      mort_regu4(:) = 0.0 !stem diameter increament in last year (m year-1)
   endif
   
!_____________ DAILY PSYSIOLOGICAL PROCESSES
   if (Logging==1) write (File_no(1),*) '    co2'        !log
   Call co2_density (LAT)
   
   if (Logging==1) write (File_no(1),*) '    air'  !log
   Call air (tmp_air(doy), humid(doy), wind(doy), ALT)
   
   if (Logging==1) write (File_no(1),*) '    radiation'  !log
   Call radiation (LAT, cloud(doy))
   par_RunningRecord(2:30) = par_RunningRecord(1:29)
   par_RunningRecord(1)    = par
   
   if (Logging==1) write (File_no(1),*) '    light_condition: diffuse'  !log
   Call diffused_radiation ()
   
   if (mod(doy,14)==0) then
   !Above line determines interval to update relative direct radiation within crown
   if (Logging==1) write (File_no(1),*) '    light_condition: direct'  !log
   Call direct_radiation ()
   end if
   
   if (Logging==1) write (File_no(1),*) '    light_condition: interruption index'  !log
   Call ir_index ()
   
!_____________ DAILY BIOLOGICAL PROCESSES
   if (Logging==1) write (File_no(1),*) '    photosynthesis_condition'  !log
   Call photosynthesis_condition (tmp_air(doy))
   
   if (Logging==1) write (File_no(1),*) '    photosynthesis'     !log
   Call photosynthesis ()
   
   if (Logging==1) write (File_no(1),*) '    lai_optimum'        !log
   Call lai_optimum (tmp_air(doy), tmp_soil(doy))
   lai_opt_grass_RunningRecord(1, 2:20) = lai_opt_grass_RunningRecord(1, 1:19)
   lai_opt_grass_RunningRecord(1, 1)    = lai_opt_grass(1)
   lai_opt_grass_RunningRecord(2, 2:20) = lai_opt_grass_RunningRecord(2, 1:19)
   lai_opt_grass_RunningRecord(2, 1)    = lai_opt_grass(2)
   
   if (Logging==1) write (File_no(1),*) '    maintenance_resp'   !log
   Call maintenance_resp (tmp_air(doy), tmp_soil(doy) )
   
   if (Logging==1) write (File_no(1),*) '    turnover'           !log
   Call turnover ()
   
   if (Logging==1) write (File_no(1),*) '    leaf_season'        !log
   Call leaf_season (LAT, tmp_soil(doy))
   
   if (Logging==1) write (File_no(1),*) '    growth_wood_daily'        !log
   Call growth_wood ()
   
   if (Logging==1) write (File_no(1),*) '    growth_grass'        !log
   Call growth_grass ()

!_____________ MONTHLY BIOLOGICAL PROCESSES
IF ( Day_of_Month(doy) == Day_in_month(Month(doy)) ) then
   
   !spacial limitation on tree growth
   if (Logging==1) write (File_no(1),*) '    spacial_limitation'  !log
    Call spacial_limitation ()
   
   !tree growth
   if (Logging==1) write (File_no(1),*) '    growth_trunc'         !log
    Call growth_trunc ()
   
   !Decomposition (from LPJ)
   if (Logging==1) write (File_no(1),*) '    decompostion'        !log
   Call decomposition (W_sat)
  
END IF

!_____________ ANNUALY BIOLOGICAL PROCESSES
IF ( doy==1 ) then
   
   if (Logging==1) write (File_no(1),*) '    pft_present'       !log
   Call pft_present ()
   
ENDIF

IF ( doy==365 ) then
   
   if (Logging==1) write (File_no(1),*) '    crown_adjust'      !log
   Call crown_adjust ()
   
   if (Logging==1) write (File_no(1),*) '    crown_shake'      !log
   Call crown_shake ()
   
   if (Logging==1) write (File_no(1),*) '    mortality'         !log
   Call mortality ()
   
   !establishment of woody PFTs
   x = sum(prec_RunningRecord(1:365))            !annual precipitation (mm/year)
   y = sum(tmp_air_RunningRecord(1:365)) / 365.0 !annual mean temperature (Celcius)
   if ( x > max(100.0, 20.0*y) ) then            !from Koppen's criteria (1936)
      
      if (Logging==1) write (File_no(1),*) '    ground_vacant'     !log
       Call ground_vacant ()
       
      if (Logging==1) write (File_no(1),*) '    establish'         !log
       Call establish ()
       
   end if
   
   if (Logging==1) write (File_no(1),*) '    grass priority change' !log
   Call grass_priority ()
   
   if (Logging==1) write (File_no(1),*) '    fire_regime'           !log
   Call fire_regime (W_sat)
   
   if (Logging==1) write (File_no(1),*) '    biome_determine'   !log
   Call biome_determine (W_fi, W_wilt)
   
END IF


!_____________ DAILY UPDATE NET-RADIATION & SOIL-WATER STATUS
   if (Logging==1) write (File_no(1),*) '    net_radiation'      !log
   Call net_radiation (tmp_air(doy), cloud(doy), Albedo_soil0)
   
   if (Logging==1) write (File_no(1),*) '    waterbudget'        !log
   Call waterbudget &
   (tmp_air(doy), tmp_soil(doy), prec(doy), wind(doy), W_fi, W_wilt, W_sat, W_mat)
   
!_____________ MAKE OUTPUT FILES
   IF (Flag_output_write) then
   
   !Daily output (everyday)
   Call output_for_viewer &
   (File_no(2), LAT, LON, ALT, Albedo_soil0, W_fi, W_wilt, W_sat, W_mat, &
   tmp_air(doy), tmp_soil(doy), cloud(doy), prec(doy), humid(doy), wind(doy))
   
   !Daily output (on each specifyed year)
   if (mod(year, 200)==0) then
   Call output_climate      (File_no( 3), &
   tmp_air(doy), tmp_soil(doy), cloud(doy), prec(doy), humid(doy), wind(doy))
   Call output_air          (File_no( 4))
   Call output_radiation    (File_no( 5))
   Call output_netradiation (File_no( 6))
   Call output_water        (File_no( 7), W_fi, W_wilt, W_sat, W_mat)
   Call output_grass        (File_no( 8))
   Call output_lai          (File_no( 9))
   endif
   
   !Monthly output
   if ( Day_of_Month(doy) == Day_in_month(Month(doy)) ) then
   Call output_cflux       (File_no(10))
   Call output_wflux       (File_no(11))
   Call output_ld_vertical (File_no(12))
   endif
   
   !Annual output
   if (doy == 365) then
   Call output_annual (File_no(13))
   Call output_forest (File_no(14))
   endif
   
   if (doy == 195) then
   Call output_biomass(File_no(15))
   endif
   
   ENDIF
   
END DO !The end of daily loop

!_____________ After Main-simulation-loop procedures
   close (File_no( 1))   !output_log.txt
   close (File_no( 2))   !output.txt
   close (File_no( 3))   !output_climate.txt
   close (File_no( 4))   !output_air.txt
   close (File_no( 5))   !output_radiation.txt
   close (File_no( 6))   !output_netradiation.txt
   close (File_no( 7))   !output_water.txt
   close (File_no( 8))   !output_grass.txt
   close (File_no( 9))   !output_lai.txt
   close (File_no(10))   !output_flux.txt
   close (File_no(11))   !output_wflux.txt
   close (File_no(12))   !output_ld_vertical.txt
   close (File_no(13))   !output_annual.txt
   close (File_no(14))   !output_forest.txt
   close (File_no(15))   !output_biomass.txt

IF ( Flag_spinup_write ) then
   open(File_no(1), file = Fn_spnout)
   Call spinup_out (File_no(1))
   close (File_no(1))
END IF

END SUBROUTINE main_loop
