!**************************************************************************************************
! Establishment of woody PFTs
!**************************************************************************************************
SUBROUTINE establish ()

!_____________ Set variables
!Namespace
   USE data_structure
   USE time_counter
   USE vegi_status_current1
   USE vegi_status_record
   USE grid_status_current1
   USE grid_status_current2
   USE grid_status_record
   implicit none
   
!Local parameter
   real,parameter::Thres_stat_water_dry = 0.3 !Threshold stat_water to determine dry month
   
!Local variables
   real   ,dimension(PFT_no)::est_possibility  !see above for definition
   logical,dimension(PFT_no)::est_capacity     !see above for definition
   real   ,dimension(PFT_no)::mass_sum         !total biomass of examining tree (DM g)
   integer                    no_possible      !number of woody PFTs that can establish here
   integer,dimension(PFT_no)::dry_month        !maximum successive number of dry month
   real   ,dimension(12)    ::stat_water_month !monthly average of stat_water
   integer                    yr  !Simulation year from initialization (including spinup period)
   
   integer est_scenario_current !establishment scenario for current year
   integer new                  !number of new sapling
   integer i, j, k, p, no       !for loop counter
   real    x, y                 !for general usage

!Definitions of establishment control parameters
!   P_establish
!      Actual establishment rate when a establishment patch was assigned to a PFT
!   
!   Est_pft_OnOff:
!      establishment switch (for Scenerio 1)
!      .true.  -> allow establish
!      .false. -> do not allow establish
!   
!   Est_year_change
!      lenght of year until establishment pattern will change (for Scenerio 3, 4)
!   
!   Est_frac_random
!      Fraction of random establishment after Est_year_change (for Scenerio  4)

!Definitions of establishment regulator (PFT specific variables)
!   est_capacity
!      It indicates wheather a PFT can establish or not on this site (true or false)
!   
!   est_possibility
!      Frequency that a establishment patch is allocated to a PFT
!      Thus, sum of est_possibility for all PFTs is always 1.0


!_____________ calculate year of this simulation
   yr = int( (counter-1)/365 ) + 1

!_____________ Determine to prceed establishment process
!If tree number is maximum, omit entire subroutine
   no = 0
   do i=1, Max_no
     if (tree_exist(i)) no=no+1
   end do
   if (no >= Max_no) return
   
!If fire occured within 10 years, omit entire subroutine
!   if ( counter-fire_clo <= 10*365 ) return

!_____________ Compute variables that control establishment
!dry_month(1:PFT_no), maximum consecutive of drought month for each PFT
   dry_month(1:PFT_no) = 0
   Do p=1, PFT_no
      stat_water_month(1:12) = 0.0
      
      !sum up stat_water for each month
      Do i=1, 365
         stat_water_month(Month(i)) = stat_water_month(Month(i)) + stat_water_RunningRecord(p,i)
      End do
      
      !make average of stat_water for each month
      Do i=1, 12
         stat_water_month(i) = stat_water_month(i) / real(Day_in_month(i))
      End do
      
      !determine maximum consecutive of drought month for each PFT
      k = 0
      Do i=1, 12*2
         j=i ; if (i>12) j=i-12 !j: month to refer
         k=k+1                  !k: current consective dry month
         if (stat_water_month(j) > Thres_stat_water_dry) k=0
         dry_month(p) = max(dry_month(p), k)
      End do
      dry_month(p) = min(dry_month(p), 12)
      
   End do
   
!est_capacity(1:PFT_no), establishment potential for each PFT based on climatic range
   est_capacity(:) = .true.
   x = sum( par_grass_RunningRecord(1:365) ) / 365.0
   do p = 1, PFT_no
      if ( p==c3g_no .or. p==c4g_no             ) est_capacity(p)=.false.
      if ( tmp_coldest_20yr_ave >=   TC_max(p)  ) est_capacity(p)=.false.
      if ( gdd_20yr_ave         <=   GDD_min(p) ) est_capacity(p)=.false.
      if ( dry_month(p)         >    DM_max(p)  ) est_capacity(p)=.false.
      if ( x                    <=   PAR_min(p) ) est_capacity(p)=.false.
   end do
   
!mass_sum(1:PFT_no), sum of biomass for each woody PFT with establishment capacity
   mass_sum(:) = 0.0
   do no = 1, Max_no
   if ( tree_exist(no) .and. est_capacity(pft(no)) ) then
      mass_sum(pft(no)) = mass_sum(pft(no)) + &
      mass_leaf(no)+mass_trunk(no)+mass_root(no)+mass_available(no)+mass_stock(no)
   end if
   end do
   
!_____________ Compute establishment probability for each PFT
!Initialize variables
   est_possibility(1:PFT_no)= 0.0 !establishment probability, a scenario specific value
   no_possible              = 0   !number of PFT that establish at this site

!Determine establishment pattern of current year
Select case (Est_scenario)
   Case (0)
      est_scenario_current = 0
   Case (1)
      est_scenario_current = 1
   Case (2)
      est_scenario_current = 2
   Case (3)
      if (yr>=Est_year_change .and. counter-fire_clo>=Est_year_change*365) then
         est_scenario_current = 3
      else
         est_scenario_current = 2
      endif
   Case (4)
      if (yr>=Est_year_change .and. counter-fire_clo>=Est_year_change*365) then
         est_scenario_current = 4
      else
         est_scenario_current = 2
      endif
End select

!Modification of establishment pattern for wet tropical regions
   if (biome==3 .or. biome==4) est_scenario_current=2

!Give establishment probability according to the establishment pattern
Select case (est_scenario_current)
   Case (1) !only specified woody PFTs can establish
      do p = 1, PFT_no
      if ( est_capacity(p) .and. Est_pft_OnOff(p) ) then
         no_possible        = no_possible + 1
         est_possibility(p) = 1.0
      endif
      enddo
      
   Case (2) !every potentially eatablishable PFT have same chance of establishment
      do p = 1, PFT_no
      if ( est_capacity(p) ) then
         no_possible        = no_possible + 1
         est_possibility(p) = 1.0
      end if
      end do
      
   Case (3) !in proportion of existing biomass
      do p = 1, PFT_no
      if ( est_capacity(p) ) then
         est_possibility(p) = mass_sum(p) / max( 1.0, sum(mass_sum(:)) )
         if (est_possibility(p) > 0.00) no_possible=no_possible+1
      endif
      end do
      
   Case (4) !in proportion of existing biomass, while little portion of establishment
            !was randomly selected from all potentialy establishable PFTs
      
      do p = 1, PFT_no
         if (est_capacity(p)) no_possible=no_possible+1
      enddo
      
      do p = 1, PFT_no
      if (est_capacity(p)) then
         x = Est_frac_random / max(1, no_possible)                      !fraction stochastic
         y = (1.0-Est_frac_random) * (mass_sum(p) / max(1.0,sum(mass_sum))) !fraction deterministic
         est_possibility(p) = est_possibility(p) + x + y
      endif
      end do
      
End select

!Adjust est_possibility, so that sum of value will be 1.0
   est_possibility(:) = est_possibility(:) / real( max(1, no_possible) )

!_____________ Establishment processes
if (no_possible == 0) return

!loop for each ground mesh
new = 1
Do i = 1, Dived
Do j = 1, Dived
   
   !K: determin PFT of newly establish tree
   x = randf()
   k = 1
   do while ( sum(est_possibility(1:k)) < x .and. k<PFT_no)
      k = k+1
   end do
   
   !x: adjusted establishment rate of PFT k
   x = P_establish(k) * real(Max_loc**2) / real(Dived**2)
   
if ( patch_vacant(i,j) ) then
if ( x > randf() ) then
   !determine new sapling ID-number
   do while ( tree_exist(new) )
      new = new + 1
   end do
   if ( new > Max_no ) return
   
   !initiate new sapling
   pft       (new) = k
   tree_exist(new) = .true.
   
   bole_x    (new) = real(i) * ( real(Max_loc) / real(Dived) ) - 0.5*real(Max_loc)/real(Dived)
   bole_y    (new) = real(j) * ( real(Max_loc) / real(Dived) ) - 0.5*real(Max_loc)/real(Dived)
   crown_x   (new) = bole_x (new)
   crown_y   (new) = bole_y (new)
   
   age           (new) = 1
   dbh_sapwood   (new) = 0.01   ! <--- this value determine initial size of new sapling
   dbh_heartwood (new) = 0.00
   height        (new) = h(dbh_sapwood(new) + dbh_heartwood(new), pft(new))
   bole          (new) = 0
   crown_area    (new) = 0.06  ! <--- this value determine initial size of crown area
   crown_diameter(new) = 2 * sqrt(crown_area(new)/PI)
   la            (new) = 0.0   !alternative:  2.0 * crown_area(new) * height(new) * STEP
   mort_regu1    (new) = 0.0
   mort_regu2    (new) = la(new) / 365
   mass_leaf     (new) = 0.0   !alternative:  la(new) / SLA(pft(new))
   mass_root     (new) = 0.0   !alternative:  mass_leaf(new) / FR_ratio(pft(new))
   mass_trunk    (new) = stem_weight(dbh_sapwood(new)+dbh_heartwood(new), height(new), pft(new))
   mass_stock    (new) = 250.0
   mass_available(new) = 250.0
   
   height_limit  (new) = height(new)
   radius_limit  (new) = sqrt(crown_area(new)/PI)
   
   stat_leaf              (new)   = 0.00
   stat_leaf_crowntop     (new)   = stat_leaf(new)
   stat_leaf_crownbottom  (new,:) = stat_leaf(new)
   
   !Adjust carbon balance
   x           = mass_leaf(new) + mass_trunk(new) + mass_root(new) + &
                 mass_stock(new) + mass_available(new)
   pool_litter = max(0.0, pool_litter - x)
   
end if
end if
End do
End do

END SUBROUTINE establish



!**************************************************************************************************
! Change priority grass
!**************************************************************************************************
SUBROUTINE grass_priority ()

!_____________ Set variables
!Namespace
   USE data_structure
   USE vegi_status_current1
   USE vegi_status_record
   implicit none
   
!Local variables
   real    x !for temporal usage
   integer i !for temporal usage
   logical l !for temporal usage
   
!_____________ Main procedure
IF     (type_grass==4 .and. npp_annual(C3g_no)*9.0>npp_annual(C4g_no) ) then
   !C4 -> C3 change
   if (Logging==1) then
      write (*,*) 'priority grass changed: C4 -> C3', npp_annual(C3g_no)*9.0, npp_annual(C4g_no)
      write (*,*)
   endif
   
   type_grass  = 3
   
   x=gmass_leaf     (1) ; gmass_leaf     (1)=gmass_leaf     (2) ; gmass_leaf     (2)=x
   x=gmass_root     (1) ; gmass_root     (1)=gmass_root     (2) ; gmass_root     (2)=x
   x=gmass_available(1) ; gmass_available(1)=gmass_available(2) ; gmass_available(2)=x
   x=gmass_stock    (1) ; gmass_stock    (1)=gmass_stock    (2) ; gmass_stock    (2)=x
   l=phenology (C3g_no) ; phenology (C3g_no)=phenology (C4g_no) ; phenology (C4g_no)=l
   i=pheno_clo (C3g_no) ; pheno_clo (C3g_no)=pheno_clo (C4g_no) ; pheno_clo (C4g_no)=i
   i=pheno_cls (C3g_no) ; pheno_cls (C3g_no)=pheno_cls (C4g_no) ; pheno_cls (C4g_no)=i
   
ELSEIF (type_grass==3 .and. npp_annual(C3g_no)<npp_annual(C4g_no)*9.0 ) then
   !C3 -> C4 change
   if (Logging==1) then
      write (*,*) 'priority grass changed: C3 -> C4', npp_annual(C3g_no), npp_annual(C4g_no)*9.0
      write (*,*)
   endif
   
   type_grass  = 4
   
   x=gmass_leaf     (1) ; gmass_leaf     (1)=gmass_leaf     (2) ; gmass_leaf     (2)=x
   x=gmass_root     (1) ; gmass_root     (1)=gmass_root     (2) ; gmass_root     (2)=x
   x=gmass_available(1) ; gmass_available(1)=gmass_available(2) ; gmass_available(2)=x
   x=gmass_stock    (1) ; gmass_stock    (1)=gmass_stock    (2) ; gmass_stock    (2)=x
   l=phenology (C3g_no) ; phenology (C3g_no)=phenology (C4g_no) ; phenology (C4g_no)=l
   i=pheno_clo (C3g_no) ; pheno_clo (C3g_no)=pheno_clo (C4g_no) ; pheno_clo (C4g_no)=i
   i=pheno_cls (C3g_no) ; pheno_cls (C3g_no)=pheno_cls (C4g_no) ; pheno_cls (C4g_no)=i
   
END IF

END SUBROUTINE grass_priority



!**************************************************************************************************
! Fire regime (for each year calculation)
!**************************************************************************************************
Subroutine fire_regime (W_sat)

!_____________ Set variables
!Namespace
   USE data_structure
   USE time_counter
   USE vegi_status_current1
   USE vegi_status_current2
   USE grid_status_current1
   USE grid_status_record
   implicit none
   
!Local parameter
   !minimum stock mass of grass layer (g DM/m2)
   real,parameter::Min_gmass_stock= 50.0
   
!Augment
   real,intent(IN):: W_sat        !saturate point   (m3/m3, 0.0 -> 1.0)
   
!Local variables
   real moist_factor !adjusted moisture factor for fire spread
   real fire_factor  !factor for fire probability calculation
   
   real,dimension(PFT_no)::mass_sum     !total aboveground biomass for each PFT (g/stand)
   real                    mass_overall !total aboveground biomass in this stand (g/stand)
   
   integer no              !loop counter for individual trees
   integer i               !loop counter
   real    fire_prob       !probability of fire occurance in a year
   real    a1, a2, x       !for general usage
   
!_____________ moist_factor calculation
   !Reset local variables
   mass_sum(:)  = 0.0
   mass_overall = 0.0
   moist_factor = 0.0
   
   !mass_total(PFT_no): total above ground biomass for each PFT
      !woody PFTs
      Do no = 1, Max_no
      if (tree_exist(no)) then
         mass_sum(pft(no)) = mass_sum(pft(no)) + mass_leaf(no) + & 
                             mass_trunk(no) + mass_available(no)   
      end if
      End do
      
      !herbaceous PFTs
      a1 = gmass_leaf(1) + gmass_available(1) !above ground biomass of C3 glass for unit area
      a2 = gmass_leaf(2) + gmass_available(2) !above ground biomass of C4 glass for unit area
      
      if (type_grass==3) then
         mass_sum(C3g_no) = a1 * real(Max_loc)*real(Max_loc) * 0.9
         mass_sum(C4g_no) = a2 * real(Max_loc)*real(Max_loc) * 0.1
      else
         mass_sum(C3g_no) = a1 * real(Max_loc)*real(Max_loc) * 0.1
         mass_sum(C4g_no) = a2 * real(Max_loc)*real(Max_loc) * 0.9
      endif
   
   !mass_overall: total biomass in this grid
   mass_overall = sum(mass_sum) !grand total biomass in this forest stand
   mass_overall = max(0.01, mass_overall)
   
   !moistfactor: adjusted litter moisture weighting factor
   Do i = 1, PFT_no
      moist_factor = moist_factor + Moisture_extinction(i) * (mass_sum(i) / mass_overall)
   End do
   
   !adjust to the upper limit and lower limit of the value
   moist_factor = min(1.0, max(0.01, moist_factor))
   

!_____________ Fire_factor (for disturbance computation)
   fire_factor=0.0
   
   do i=1, 365
   x           = pool_w1_RunningRecord(i) / (Depth1*W_sat)
   fire_factor = fire_factor + exp( -PI * ((x/moist_factor)**2) ) / 365.0
   end do
   
!_____________ Fire_prob: calculate fire probability [A(s) in eq.37]
   x         = fire_factor - 1.0
   fire_prob = fire_factor * EXP( x / (0.45*x*x*x + 2.83*x*x + 2.96*x + 1.04) )
   
!_____________ Examine this site satisfies minimum-fuel-load
   !x: total fuel load in this forest stand (g C / m2)
   x = pool_litter + pool_trunc + pool_leaf + pool_root + pool_grass_up
   x = x * C_in_drymass / (Max_loc * Max_loc)
   if ( Fuel_min > x  ) fire_prob = 0.0

!TMP (for succession experiment1)
!if ( mod(year, 130)==1 ) then !for each 130yr interval
!       fire_prob = 1.0
!else
!       fire_prob = 0.0
!endif

!_____________ When fire occurs
   If ( (fire_prob>randf()) .and. (counter-fire_clo>365) ) then
      if (Logging==1) write(*,*) 'Fire occured!, ', counter
      fire_clo = counter
      
      !Litter pool -> 50% lost
      c_emission   = c_emission + 0.50 * pool_litter * C_in_drymass
      pool_litter  = 0.50 * pool_litter
      
      !Grass PFTs -> total above ground biomass lost
      c_emission = c_emission + C_in_drymass * pool_grass_up
      gmass_leaf (1) = 0.0
      gmass_leaf (2) = 0.0
      
      if (type_grass==3) then
         x = 0.9 * Max_loc * Max_loc * max( 0.0 , Min_gmass_stock - gmass_stock(1) ) + &
             0.1 * Max_loc * Max_loc * max( 0.0 , Min_gmass_stock - gmass_stock(2) )    
      else
         x = 0.1 * Max_loc * Max_loc * max( 0.0 , Min_gmass_stock - gmass_stock(1) ) + &
             0.9 * Max_loc * Max_loc * max( 0.0 , Min_gmass_stock - gmass_stock(2) )    
      end if
      pool_litter = max(0.0, pool_litter - x)
      
      gmass_stock(1) = max( gmass_stock(1), Min_gmass_stock )
      gmass_stock(2) = max( gmass_stock(2), Min_gmass_stock )
      
      !Woody PFT: A fraction of trees were killed, and their above ground biomass lost
      Do no = 1, Max_no
      if (tree_exist(no)) then
      if ( randf() >  M3(pft(no)) ) then
         !for dead plants
         c_emission   = c_emission                           + &
                        C_in_drymass * mass_leaf(no)         + &
                        C_in_drymass * mass_trunk(no) * 0.50    
         
         pool_litter = pool_litter                           + &
                       mass_trunk(no) * 0.50                 + &
                       mass_root(no)                         + &
                       mass_stock(no)                        + &
                       mass_available(no)                       
         
         tree_exist(no)      = .false.
         pft(no)            = 0
         age(no)            = 0
         height(no)         = 0
         bole(no)           = 0
         dbh_sapwood(no)    = 0.0
         dbh_heartwood(no)  = 0.0
         crown_area(no)     = 0.0
         crown_diameter(no) = 0.0
         la(no)             = 0.0
         mass_leaf(no)      = 0.0
         mass_root(no)      = 0.0
         mass_trunk(no)     = 0.0
         mass_stock(no)     = 0.0
         mass_available(no) = 0.0
      else
         !for survived trees
         c_emission    = c_emission + C_in_drymass * mass_leaf(no)
         mass_leaf(no) = 0.0
         la(no)        = 0.0
      end if
      end if
      End do
      
        !Deciduous PFTs -> change to dormance phase
      Do i=1, PFT_no
      if ( Phenology_type(i) .ne. 0.0 ) then 
         phenology(i) = .false.
      End if
      End do
      
   Endif
   
End subroutine fire_regime



!**************************************************************************************************
! mortality of individual 'no' for the current year
!**************************************************************************************************
SUBROUTINE mortality ()

!_____________ Set variables
!Namespace
   USE data_structure
   USE vegi_status_current1
   USE vegi_status_record
   USE grid_status_current1
   USE grid_status_record
   implicit none
   
!Local parameters (Gap formation parameters from Huth & Ditzer (2000) )
   ! bottom height of forest layer no 2,3,4,5 (m) 
   !(top    height of forest layer no 1,2,3,4 (m) )
   real,dimension(4),parameter::Layer_top = (/1.3, 15.0, 25.0, 36.0/)
   
   !Threshold fraction of crown layer overlapping to declare 'crowded layer' (frac)
   real,parameter::Frac_crowded         = 1.00
   
   !Threshold Tree height to have possibility to form gap (m)
   real,parameter::Thres_height_GapForm = 25.0
   
   !Fraction of gap formation when large tree die
   real,parameter::Frac_GapForm         = 0.20
   
   !Fraction of gap formation when large tree die (m)
   real,parameter::Dist_GapEntangled    = 11.3
   
   ! for tree layer no 1,2,3,4,5 (m)
   real,dimension(5),parameter::Frac_GapEntangled = (/0.0, 0.3, 0.6, 0.8, 0.4/)
   
!Local variable
   !Frags for death assigned trees
   logical,dimension(Max_no)::death_list     
   logical,dimension(Max_no)::death_list_gap 
   
   !Mortality component
   real mort_greff   !mortality as a result of low growth efficiency
   real mort_heart   !mortality as a result of heart stress
   real mort_lim     !mortality as a result of bioclimic limits
   real mort_etc     !mortality as a result of other factors
   real mort_total   !mortality as a result of above all factors
   
   !From embedding FORMIX3
   real   ,dimension(5)     ::layer_ca      !Crown area for each layer (m2)
   logical,dimension(5)     ::layer_crowded !crowded flag for each crown layer
   integer,dimension(Max_no)::layer_belong  !crown layer number that each tree belongs
   
   !For general usage
   integer no, p, i                                 !loop counter
   real    x, y                                     !for general usage
   real    d1, d2, d3, d4, d5, d6, d7, d8, d9, dist !
   
!_____________ Determine crowded layer
   layer_ca     (:) = 0.0     !(1:Top_layer) crown area for each layer (m2)
   layer_crowded(:) = .false. !(1:Top_layer) crowded flag for each layer          
   layer_belong (:) = 0       !(1:Max_no   ) crown layer that each tree belongs   
   
   Do no=1, Max_no 
   If ( tree_exist(no) ) then
      
      x = height(no)*STEP+1.3
      
      if     ( x<Layer_top(1) ) then !crown of this tree belongs to layer 1
         layer_belong(no)=1 ; layer_ca(1)=layer_ca(1)+crown_area(no)
         
      elseif ( x<Layer_top(2) ) then !crown of this tree belongs to layer 2
         layer_belong(no)=2 ; layer_ca(2)=layer_ca(2)+crown_area(no)
         
      elseif ( x<Layer_top(3) ) then !crown of this tree belongs to layer 3
         layer_belong(no)=3 ; layer_ca(3)=layer_ca(3)+crown_area(no)
         
      elseif ( x<Layer_top(4) ) then !crown of this tree belongs to layer 4
         layer_belong(no)=4 ; layer_ca(4)=layer_ca(4)+crown_area(no)
         
      else                           !crown of this tree belongs to layer 5
         layer_belong(no)=5 ; layer_ca(5)=layer_ca(5)+crown_area(no)
         
      endif
      
   End if
   End do
   
   Do i=1, 5
      if ( layer_ca(i)/Max_loc/Max_loc > Frac_crowded ) then
         layer_crowded(i) = .true.
      endif
   End do
   
!_____________ Determine trees to be die 1
   death_list(:) = .false.
   
DO no=1, Max_no 
if ( tree_exist(no) .and. age(no)>1 ) then
   
   !reset mortality variables for each PFT
   mort_greff=0.0 ; mort_heart=0.0 ; mort_lim=0.0 ; mort_etc=0.0 ; mort_total=0.0
   
   !set pft number
    p = pft(no)
   
   !mortality 1: growth efficiency
   Select Case (Life_type(p))
      !tropical evergreen trees
      case (1) 
         
         !Under normal condition
         mort_greff = 0.0178 * exp(-242.57*mort_regu4(no))
         mort_greff = max(mort_greff, 0.0032)
         mort_greff = mort_greff * M4(p)
         
         !When crowded
         if ( layer_crowded(layer_belong(no)) ) mort_greff = M5(p)
         
      !other woody PFTs
      case default
         x      = (mort_regu1(no)/1000.0) / max(0.01, mort_regu2(no))
            !x         : Annual NPP per leaf area (Kg dm m-2)
            !mort_regu1: NPP annual (g dm / individual)
            !mort_regu2: mean leaf area of last year (m2/day)
            
         x      = max(0.0, x)
         mort_greff = M1(p) / (M2(p)**x)
            !large M2 --> intensify grouth rate efficiency to mortality rate
         
         !other method
         !x      = mort_regu1(no) / max(0.1, mort_regu2(no)) / 1000.0
         !x      = max(0.001, x)
         !mort_greff = 1.0 / ( 1.0 + M1(p) * ( x ** M2(p) ) )
         
   End select
   
   !mortality 2: heart stress
   if (Heat_sensitive(p)==1) then
      do i=1, 365
      mort_heart = min(1.0, &
                   mort_heart + max(0.0, tmp_air_RunningRecord(i)-Heat_base) / 300.0 )
      end do
   else
      mort_heart = 0.0
   end if
   
   !mortality 3: bioclimic limits (based on 20yrs mean of coldest month temperature)
   if     ( tmp_coldest_20yr_ave < TC_min(p) ) then
       mort_lim = 1.0
   elseif ( Life_type(no)==2 .and. (tmp_hottest_20yr_ave-tmp_coldest_20yr_ave)<43.0 ) then
       mort_lim = 1.0
   else
       mort_lim = 0.0
   endif
   
   !mortality 4: mortality by other factors
   if     ( height(no)-bole(no)<=2 .and. age(no)>3 )         then
      mort_etc = 1.0
   elseif ( mort_regu1(no)<10.0 .and. age(no)>3 )            then
      mort_etc = 1.0
   elseif ( dbh_heartwood(no)+dbh_sapwood(no) > DBH_max(p) ) then
      mort_etc = 1.0
   elseif ( age(no) >= AGE_max(p) )                          then
      mort_etc = 1.0
   else
      mort_etc = 0.0
   endif
   
   !Sum up all mortality components, and calculate probabilty of death
   mort_total   = min(1.0, mort_greff + mort_heart + mort_lim + mort_etc)
   
   !Determine whether die
   if ( mort_total>randf() ) death_list(no) = .true.
   
end if
END DO
   
!_____________ Determine trees to be die 2 (Gap formation)
   death_list_gap(:) = .false.
   
DO no=1, Max_no 
   
   !When gap forms
   if ( tree_exist(no)                             .and. &
        death_list(no)                             .and. &
        Life_type(pft(no)) == 1                    .and. &
        height(no)*STEP+1.3 > Thres_height_GapForm .and. &
        Frac_GapForm > randf()                             ) then
      
      !determine center location of new gap
      x = randf() * Max_loc !; x = max(0.0, x) ; x = min(real(Max_loc), x)
      y = randf() * Max_loc !; y = max(0.0, y) ; y = min(real(Max_loc), y)
      
      !determine which tree will die due to the gap formation
      do i=1, Max_no
      if ( tree_exist(i) .and. age(i)>1 ) then
         
         !Distance from gap center
         d1 = (x - (bole_x(i)-real(Max_loc)) )**2 + (y - (bole_y(i)-real(Max_loc)) )**2
         d2 = (x - (bole_x(i)              ) )**2 + (y - (bole_y(i)-real(Max_loc)) )**2
         d3 = (x - (bole_x(i)+real(Max_loc)) )**2 + (y - (bole_y(i)-real(Max_loc)) )**2
         d4 = (x - (bole_x(i)-real(Max_loc)) )**2 + (y - (bole_y(i)              ) )**2
         d5 = (x - (bole_x(i)              ) )**2 + (y - (bole_y(i)              ) )**2
         d6 = (x - (bole_x(i)+real(Max_loc)) )**2 + (y - (bole_y(i)              ) )**2
         d7 = (x - (bole_x(i)-real(Max_loc)) )**2 + (y - (bole_y(i)+real(Max_loc)) )**2
         d8 = (x - (bole_x(i)              ) )**2 + (y - (bole_y(i)+real(Max_loc)) )**2
         d9 = (x - (bole_x(i)+real(Max_loc)) )**2 + (y - (bole_y(i)+real(Max_loc)) )**2
         
         dist = min(d1,d2,d3,d4,d5,d6,d7,d8,d9)
         dist = sqrt(dist)
         
         if ( dist<Dist_GapEntangled ) then
         if ( Frac_GapEntangled(layer_belong(i)) > randf() ) then
            death_list_gap(i)=.true.
         endif
         endif
         
      endif
      enddo
      
   endif
   
END DO
   
!_____________ Kill assigned trees
   do no=1, Max_no 
   if (death_list(no) .or. death_list_gap(no)) then
   
   !Increase pool_litter
   pool_litter = pool_litter + &
                 mass_leaf(no) + mass_trunk(no) + mass_root(no) + &
                 mass_available(no) + mass_stock(no)
   
   !Initialize tree
   tree_exist     (no) = .false.
   pft            (no) = 0  
   age            (no) = 0  
   height         (no) = 0  
   bole           (no) = 0  
   dbh_sapwood    (no) = 0.0
   dbh_heartwood  (no) = 0.0
   crown_area     (no) = 0.0
   crown_diameter (no) = 0.0
   la             (no) = 0.0
   mort_regu1     (no) = 0.0
   mort_regu2     (no) = 0.0
   mass_leaf      (no) = 0.0
   mass_root      (no) = 0.0
   mass_trunk     (no) = 0.0
   mass_stock     (no) = 0.0
   mass_available (no) = 0.0
   
   height_limit   (no) = 0
   radius_limit   (no) = 0.0
   
   stat_leaf                 (no)   = 0.0
   stat_leaf_crowntop        (no)   = 0.0
   stat_leaf_crownbottom     (no,:) = 0.0
   
   endif
   end do
   
!_____________ Increament of tree age
   do no=1, Max_no 
   if ( tree_exist(no) ) then !when tree exist
       age(no) = age(no) + 1  !add tree age
   end if
   end do
   
END SUBROUTINE mortality
